@@ -1,7 +1,7 @@
 package Twitter::API;
 # ABSTRACT: A Twitter REST API library for Perl
 
-our $VERSION = '0.0111';
+our $VERSION = '0.0112';
 use 5.14.1;
 use Moo;
 use Carp;
@@ -436,7 +436,7 @@ Twitter::API - A Twitter REST API library for Perl
 
 =head1 VERSION
 
-version 0.0111
+version 0.0112
 
 =head1 SYNOPSIS
 
@@ -647,13 +647,13 @@ specified, e.g. C<https://api.twitter.com/1.1/account/verify_credentials.json>.
 This should accommodate any new API endpoints Twitter adds without requiring an
 update to this module.
 
-=head2 put($url, [ \%args ])
+=head2 post($url, [ \%args ])
 
 See C<get> above, for a discussion C<$url>. For file upload, pass an array
 reference as described in
 L<https://metacpan.org/pod/distribution/HTTP-Message/lib/HTTP/Request/Common.pm#POST-url-Header-Value-...-Content-content>.
 
-=head2 get_request_token([ \%args ])
+=head2 oauth_request_token([ \%args ])
 
 This is the first step in the OAuth handshake. The only argument expected is
 C<callback>, which defaults to C<oob> for PIN based verification. Web
@@ -665,20 +665,27 @@ See L<https://dev.twitter.com/oauth/reference/post/oauth/request_token>.
 
 =head2 oauth_authentication_url(\%args)
 
-This is the second step in the OAuth handshake. The only required argument is C<oauth_token>. Use the value returned by C<get_request_token>. Optional arguments: C<force_login> and C<screen_name> to prefill Twitter's authentication form.
+This is the second step in the OAuth handshake. The only required argument is
+C<oauth_token>. Use the value returned by C<get_request_token>. Optional
+arguments: C<force_login> and C<screen_name> to prefill Twitter's
+authentication form.
 
 See L<https://dev.twitter.com/oauth/reference/get/oauth/authenticate>.
 
-=head2 get_authorization_url(\%args)
+=head2 oauth_authorization_url(\%args)
 
 Identical to C<oauth_authentication_url>, but uses authorization flow, rather
 than authentication flow.
 
 See L<https://dev.twitter.com/oauth/reference/get/oauth/authorize>.
 
-=head2 get_access_token(\%ags)
+=head2 oauth_access_token(\%ags)
 
-This is the third and final step in the OAuth handshake. Pass the request C<token>, request C<token_secret> obtained in the C<get_request_token> call, and either the PIN number if you used C<oob> for the callback value in C<get_request_token> or the C<verifier> parameter returned in the web callback, as C<verfier>.
+This is the third and final step in the OAuth handshake. Pass the request
+C<token>, request C<token_secret> obtained in the C<get_request_token> call,
+and either the PIN number if you used C<oob> for the callback value in
+C<get_request_token> or the C<verifier> parameter returned in the web callback,
+as C<verfier>.
 
 See L<https://dev.twitter.com/oauth/reference/post/oauth/access_token>.
 
