@@ -1,6 +1,6 @@
 package Twitter::API::Error;
 # ABSTRACT: Twitter API exception
-$Twitter::API::Error::VERSION = '0.0111';
+$Twitter::API::Error::VERSION = '0.0112';
 use Moo;
 use Ref::Util qw/is_arrayref is_hashref/;
 use Try::Tiny;
@@ -87,7 +87,7 @@ sub twitter_error_text {
     return '' unless $self->twitter_error;
     my $e = $self->twitter_error;
 
-    return is_hash($e) && (
+    return is_hashref($e) && (
         # the newest variant: array of errors
         exists $e->{errors}
             && is_arrayref($e->{errors})
@@ -224,7 +224,7 @@ Twitter::API::Error - Twitter API exception
 
 =head1 VERSION
 
-version 0.0111
+version 0.0112
 
 =head1 SYNOPSIS
 
